<?php

declare(strict_types = 1);

namespace Drupal\group_finder;

/**
 * Class GroupFinderFactory.
 *
 * A simple factory class used for getting the applicable group finder plugin.
 */
class GroupFinderFactory implements GroupFinderFactoryInterface {

  /**
   * The group finder plugin manager.
   *
   * @var \Drupal\group_finder\GroupFinderManager
   */
  protected $groupFinder;

  /**
   * GroupFinderFactory constructor.
   *
   * @param \Drupal\group_finder\GroupFinderManager $group_finder_manager
   *   Group finder plugin manager.
   */
  public function __construct(GroupFinderManager $group_finder_manager) {
    $this->groupFinder = $group_finder_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function get(): ?GroupFinderInterface {
    $plugins = $this->groupFinder->getDefinitions();

    foreach ($plugins as $plugin_id => $definition) {
      /** @var \Drupal\group_finder\GroupFinderInterface $pluginInstance */
      $pluginInstance = $this->groupFinder->createInstance($plugin_id);
      if ($pluginInstance && $pluginInstance->isApplicable()) {
        return $pluginInstance;
      }
    }

    return NULL;
  }

}
